@@ -5,15 +5,16 @@
 //! `icu_provider_blob` contains implementations of the [`ICU4X`] [`DataProvider`] interface
 //! that load data from a single blob.
 //!
-//! Currently, this crate supports only static blobs, but it will soon support blobs loaded
-//! dynamically at runtime (see [#848](https://github.com/unicode-org/icu4x/issues/848)).
+//! There are two exports:
+//!
+//! 1. [`BlobDataProvider`] supports data blobs loaded dynamically at runtime.
+//! 2. [`StaticDataProvider`] supports data blobs baked into the binary at compile time.
 //!
 //! To build blob data, use the `--format blob` option of [`icu4x-datagen`]. For example, to build
 //! "hello world" data, run:
 //!
 //! ```bash
 //! $ cargo run --bin=icu4x-datagen -- \
-//!     -v \
 //!     --format blob \
 //!     --hello-world-key \
 //!     --all-locales \
@@ -28,6 +29,8 @@
 //! let _ = icu_testdata::get_static_provider();
 //! ```
 //!
+//! For more examples, see the specific data providers.
+//!
 //! [`ICU4X`]: ../icu/index.html
 //! [`DataProvider`]: icu_provider::prelude::DataProvider
 //! [`icu4x-datagen`]: https://github.com/unicode-org/icu4x/tree/main/tools/datagen#readme
@@ -36,6 +39,7 @@
 
 extern crate alloc;
 
+mod blob_data_provider;
 mod blob_schema;
 mod path_util;
 mod static_data_provider;
@@ -43,4 +47,5 @@ mod static_data_provider;
 #[cfg(feature = "export")]
 pub mod export;
 
+pub use blob_data_provider::BlobDataProvider;
 pub use static_data_provider::StaticDataProvider;
